@@ -12,6 +12,7 @@ switchDeps = c(basepkgs, "switchr", "RCurl", "bitops", "BiocInstaller", "RJSONIO
 ##' @note By default switchr will not attempt to unload any base packages,
 ##' itself, or any of its dependencies. Attempting to unload any of these
 ##' packages will result in undefined behavior and is not recommended.
+##' @importFrom tools package_dependencies
 ##' @export
 switchrDontUnload = function(value, add=TRUE) {
     if(missing(value)){
@@ -19,13 +20,39 @@ switchrDontUnload = function(value, add=TRUE) {
             switchrOpts$dontunload = switchDeps
         switchrOpts$dontunload
     } else {
+        deps = package_dependencies(value,
+            db = available.packages(contrib.url(defaultRepos())),
+            recursive=TRUE)
+        ## not unloading a package makes no sense if you don't also keep it's
+        ## dependencies 
+        value = unique(c(names(deps), unlist(deps, recursive=TRUE)))
         if(add)
             value = unique(c(switchrDontUnload(), value))
         switchrOpts$dontunload = value
     }
 
 }
-        
+
+##' Skip unloading of packages in session
+##' @param value A logical value, or missing to return the current option
+##' @return A logical indicating whether or not calling \code{flushSession} will skipped during the library switching process.
+##' @details This should be set to TRUE  when using switchr in the context of dynamic documents such as .Rnw and .Rmd files. 
+##' @export
+##' 
+switchrNoUnload = function(value) {
+    if(missing(value)){
+        if(is.null(switchrOpts$noflush)) 
+            switchrOpts$noflush = FALSE
+        switchrOpts$noflush
+    } else {
+        if(is.na(value))
+            value = FALSE
+        if(!is(value, "logical"))
+            stop("The no unload option must be a logical value") 
+        switchrOpts$noflush = value
+    }
+    
+}
 
 ##' flushSession
 ##' Unload currently loaded packages from the current R session
